@@ -779,14 +779,13 @@ nsBoxFileUploader.prototype = {
     req.setRequestHeader("Authorization", "Bearer " + this.box._oauth.accessToken);
 
     // Encode the form.
-    File.createFromNsIFile(this.file).then(file => {
-      let form = Cc["@mozilla.org/files/formdata;1"]
-                   .createInstance(Ci.nsIDOMFormData);
-      form.append("filename", file, this.file.leafName);
-      form.append("parent_id", this.box._cachedFolderId);
+    let file = File.createFromNsIFile(this.file);
+    let form = Cc["@mozilla.org/files/formdata;1"]
+                 .createInstance(Ci.nsIDOMFormData);
+    form.append("filename", file, this.file.leafName);
+    form.append("parent_id", this.box._cachedFolderId);
 
-      req.send(form);
-    });
+    req.send(form);
   },
 
   /**
